@@ -31,8 +31,8 @@
 
 #include "SDL.h"
 
-#include "SDL_framerate.h"
-#include "SDL_gfxPrimitives.h"
+#include "SDL/SDL_framerate.h"
+#include "SDL/SDL_gfxPrimitives.h"
 
 void HandleEvent()
 {
@@ -118,7 +118,7 @@ void Draw(SDL_Surface *screen)
   circleRGBA(screen,x,y,30,255,255,255,255);
     
   /* Display by flipping screens */
-  SDL_UpdateRect(screen,0,0,0,0);
+  SDL_Flip(screen);
 
   /* Delay to fix rate */                   
   SDL_framerateDelay(&fpsm);  
